H5_file_name = '/Users/phil/Dropbox/Autocurator/testing_data/MP4s/AH0667x170317_JON/AH0667x170317-.h5'
label_key = 'labels'



from PSM_testbed.WhACC.touch_curation_GUI import touch_gui

touch_gui(H5_file_name, label_key)



# import tensorflow as tf
from PSM_testbed.WhACC import utils
from PSM_testbed.WhACC import image_tools


#
# m_list = utils.get_model_list('/Users/phil/Dropbox/Colab data/model_iterations')
#
# H5_list = ['/Users/phil/Dropbox/Autocurator/testing_data/MP4s/AH0667x170317_JON/AH0667x170317-.h5']
#
# model_2_load = m_list[15]
# # MOD_BASE_NAME = model_2_load.split('/')[-1].split('.')[0]
# model = tf.keras.models.load_model(model_2_load)
# gen = image_tools.ImageBatchGenerator(1000, H5_list)
# predictions = model.predict(gen, verbose = 1)
# ###

# h5_list = utils.get_h5s('/Users/phil/Dropbox/Autocurator/testing_data/MP4s/')
# h5_2_load = h5_list[2]

m_list = utils.get_model_list('/Users/phil/Dropbox/Colab data/model_iterations')
model_2_load = m_list[12]

# H5_list = [h5_2_load]
H5_list = utils.get_h5s('/Users/phil/Dropbox/Autocurator/testing_data/MP4s/')
H5_file = image_tools.run_multiple_H5_files(H5_list,
                                            model_2_load,
                                            append_model_and_labels_to_name_string = False,
                                            batch_size = 1000,
                                            save_on = True,
                                            label_save_name = 'labels')

import h5py
import matplotlib.pyplot as plt
for k in H5_list:
    with h5py.File(k, 'r') as hf:
            plt.plot(hf['labels'][:])



# import h5py
# import matplotlib.pyplot as plt
# h5_file_name = '/Users/phil/Dropbox/Autocurator/testing_data/MP4s/AH0667x170317_JON/AH0667x170317-.h5'
# with h5py.File(h5_file_name, 'r') as hf:
#     # print(hf['labels'])
#     for k in hf.keys():
#         print(k)
#     plt.plot(hf['MODEL__resnet50 regular images full unfrozen20201028FULL__labels'][:])
# #



from setuptools import setup
from setuptools import find_packages


setup(name='PSM_testbed',
      version='0.0.0.26',
      description='A testbed package for Phillip Maire',
      packages=find_packages(),
      author_email='phillip.maire@gmail.com',
      zip_safe=False,
      install_requires=[
       # "pyicu",
       "natsort==7.1.1"])
#      packages=['PSM_testbed'],



# from PSM_testbed.WhACC import subset_H5_generator
from PSM_testbed.WhACC import utils
from PSM_testbed.WhACC.subset_h5_generator import subset_h5_generator
H5_list = utils.get_h5s('/Users/phil/Dropbox/Autocurator/testing_data/MP4s/')

sg = subset_h5_generator(H5_list[0], 'labels')

sg.get_example_segments(seg_len_look_dist=10,
                             min_y=.9,
                             max_y=1,
                             num_to_sample=10,
                             num_high_prob_past_max_y=10,
                             start_and_stop_pole_times = [2000, 3000])

sg.plot_all_onset_or_offset(sg.onset_list, fig_size = [10, 10])
sg.plot_all_onset_or_offset(sg.offset_list, fig_size = [10, 10])

# import numpy as np
# import h5py
# frame_inds = [1, 2, 3]
# h5_img_key = 'images'
# im_stack = None
# for k in frame_inds:
#     with h5py.File(sg.h5_img_file, 'r') as h:
#         x = np.asarray(h[h5_img_key][k])
#         if im_stack is None:
#             im_stack = x
#         else:
#             im_stack = np.hstack((im_stack, x))
